ods graphics off;

*Designate library names for data folders;
libname call "D:\Data\commercial bank quarterly files"; /*folder for Call Reports*/
libname dlr "C:\Dropbox\Securitization\Submission\JAR - Final"; /*folder for the main folder for the project*/

*Import Call Reports to the working space;
data call_all; set 
call.call199703 call.call199706 call.call199709 call.call199712
call.call199803 call.call199806 call.call199809 call.call199812
call.call199903 call.call199906 call.call199909 call.call199912
call.call200003 call.call200006 call.call200009 call.call200012
call.call200103 call.call200106 call.call200109 call.call200112
call.call200203 call.call200206 call.call200209 call.call200212
call.call200303 call.call200306 call.call200309 call.call200312
call.call200403 call.call200406 call.call200409 call.call200412
call.call200503 call.call200506 call.call200509 call.call200512
call.call200603 call.call200606 call.call200609 call.call200612
call.call200703 call.call200706 call.call200709 call.call200712
call.call200803 call.call200806 call.call200809 call.call200812
call.call200903 call.call200906 call.call200909 call.call200912
call.call201003 call.call201006 call.call201009 call.call201012;
run;

*Keep only relevant variables and generate key variables to estimate DLR at the bank level;
data call_1; set call_all;
keep date rssd9001 rssd9010 rssd9017 rssd9348 rssd9364 rssd9200 zip_code state_code asset lnat year loan npl npl_num cash deposit liq llr roa tieronecap llp_raw ebllp_raw alwn equity_to_asset;
format date yymmddn8.;
date=mdy(floor((RSSD9999-floor(RSSD9999/10000)*10000)/100),RSSD9999-floor(RSSD9999/10000)*10000-floor((RSSD9999-floor(RSSD9999/10000)*10000)/100)*100,floor(RSSD9999/10000));
if rcfd2170=. then delete; /*remove obs. with missing assets*/
asset=rcfd2170;
lnat=log(rcfd2170);
year=year(date);
loan=rcfd2122;
npl=sum(rcfd1403,rcfd1407)/rcfd2170;
npl_num=sum(rcfd1403,rcfd1407);
tieronecap=rcfd8274/rcfda223;
cash=sum(rcfd0081,rcfd0071)/rcfd2170;
deposit=sum(rcon2215,rcon2385)/rcfd2170;
liq=rcfd2122/sum(rcon2215,rcon2385);
llr=rcfd3123/rcfd2170;
roa=riad4340/rcfd2170;
llp_raw=riad4230;
ebllp_raw=(riad4301+riad4230);
zip_code=substrn(rssd9220, 1, 5)*1;
state_code=rssd9210;
alwn=rcfd3123/sum(rcfd1403,rcfd1407);
equity_to_asset=rcfd3210/rcfd2170;
run;

proc sort data=call_1; by rssd9001 date; quit;

*Create lagged variables;
data call_1; set call_1; by rssd9001 date;
lag_loan=lag(loan); lag_npl_num=lag(npl_num); lag_at=lag(asset); lag_lnat=lag(lnat); lag_tieronecap=lag(tieronecap);
if first.rssd9001 then do; 
lag_loan=.;lag_npl_num=.;lag_at=.;lag_lnat=.;lag_tieronecap=.;
end;
run;

*Adjust quarterly variables on the income statement;
data call_1; set call_1;
if rssd9001=lag1(rssd9001) then lag1=1; else lag1=.;
if rssd9001=lag4(rssd9001) then lag4=1; else lag4=.;
llp_adj=llp_raw-lag1(llp_raw)*lag1; if month(date)=3 then llp_adj=llp_raw;
ebllp_adj=ebllp_raw-lag1(ebllp_raw)*lag1; if month(date)=3 then ebllp_adj=ebllp_raw;
run;

data call_1 (drop=lag1 lag4 llp_raw llp_adj ebllp_raw ebllp_adj); set call_1;
llp=llp_adj/lag_loan;
d_npl=(npl_num-lag_npl_num)/lag_loan;
ebllp=ebllp_adj/lag_loan;
run;

*Create lagged variables;
data call_1; set call_1; by rssd9001 date;
lag1_d_npl=lag1(d_npl); lag2_d_npl=lag2(d_npl);
if first.rssd9001 then do; 
lag1_d_npl=.;lag2_d_npl=.;
end;
run;

*Create lead variables;
proc sort data=call_1; by rssd9001 descending date; quit;

data call_1; set call_1; by rssd9001 descending date;
lead1_d_npl=lag1(d_npl);
if first.rssd9001 then do; 
lead1_d_npl=.;
end;
run;

*Import coincident index;
data call_1; set call_1;
quarter=qtr(date);
run;

data coincident_quarterly; set dlr.coincident_quarterly; 
year=year(date);
quarter=qtr(date);
run;

proc sql;
create table call_1 as select distinct a.*, b.g_index 
from call_1 as a left join coincident_quarterly as b
on a.rssd9200 = b.state and a.year = b.year and a.quarter = b.quarter;
quit;

*Estimate DLR with regressions;
proc sort data=call_1; by rssd9001 date; quit;

**First, create rank dates to have the most recent 12 quarters for each bank and date;
data call_2; set call_1(keep=rssd9001 date); by rssd9001; 
retain firstdate;
date=intnx('quarter', date, 1)-1;
if first.rssd9001 then firstdate=date;
if last.rssd9001 then do;
lastdate=date;
output;
end;
run;
  
data call_3(rename=(date=rankdate)); set call_2;
date=firstdate;
do while(date<=lastdate);
output;
date=intnx('quarter', date+1, 1)-1;
end;
run;

data call_4; set call_3;
date=rankdate;
i=1;
do while(i<=12);
output;
date=intnx('quarter', date, 0)-1;
i=i+1;
end;
format date yymmddn8.;
run;

**Then, combine with those variables in equations (A1) and (A2) to estimate DLR; 
proc sql;
create table call_5 as select distinct a.*, b.llp, b.d_npl, b.lag1_d_npl, b.lag2_d_npl, b.lead1_d_npl, b.ebllp, b.lag_lnat,
b.lag_tieronecap, b.g_index 
from call_4 as a left join call_1 as b
on a.rssd9001 = b.rssd9001 and a.date = b.date;
quit;

data call_6; set call_5;
if rankdate>'30sep2000'd;
run;

proc sort data=call_6; by rssd9001 rankdate; quit; 

***Estimate equation (A1);
proc reg data=call_6 noprint adjrsq outest=estimates1;
by rssd9001 rankdate;
model llp = lag2_d_npl lag1_d_npl ebllp lag_tieronecap lag_lnat g_index;
options nonotes; quit;

data estimates1; set estimates1;
if _edf_>=5; /*require the bank to have data for all 12 quarters*/
run;

***Estimate equation (A2);
proc reg data=call_6 noprint adjrsq outest=estimates2;
by rssd9001 rankdate;
model llp = lag2_d_npl lag1_d_npl d_npl lead1_d_npl ebllp lag_tieronecap lag_lnat g_index;
options nonotes; quit;

data estimates2; set estimates2;
if _edf_>=3; /*require the bank to have data for all 12 quarters*/
run;

proc sql;
create table estimates1 as select distinct a.*, b._ADJRSQ_ as _ADJRSQ_2
from estimates1 as a left join estimates2 as b
on a.rssd9001 = b.rssd9001 and a.rankdate = b.rankdate;
quit;

***Take the difference between Adj. R2s of equations (A1) and (A2);
data estimates1; set estimates1;
delr=_ADJRSQ_-_ADJRSQ_2;
year=year(rankdate);
if delr=. then delete;
run;

*Create yearly DLR by averaging quarterly DLR;
proc means data=estimates1 noprint; by rssd9001 year; 
output out=delr_year 
mean(delr)=delr_avg p50(delr)=delr_med;
quit; 

proc sort data=delr_year; by rssd9001 year; quit; 

*Construct the yearly bank data by combining DLR measure;
data call_7; set call_1;
if month(date)=12;
run;

proc sql;
create table call_7 as select a.*, b.delr
from call_7 as a left join estimates1 as b
on a.rssd9001 = b.rssd9001 and a.date = b.rankdate; 
quit;

*Create other versions of DLR;
data call_7; set call_7;
if date='31dec2006'd then delr_2006q4=delr;
if date='31dec2001'd then delr_2001q4=delr;
if date='31dec2006'd then alwn_2006q4=alwn;
if date='31dec2001'd then alwn_2001q4=alwn;
run;
proc sql;
create table call_7 as
select *, max(delr_2001q4) as delr_2001, max(delr_2006q4) as delr_2006, max(alwn_2001q4) as alwn_2001, max(alwn_2006q4) as alwn_2006
from call_7
group by rssd9001;
quit;

*Combine with other bank-level variables;
proc sql;
create table delr_year as select a.*, b.rssd9010, b.rssd9017, b.delr_2001, b.delr_2006, b.alwn, b.alwn_2001, b.alwn_2006, b.asset, b.lnat, 
b.tieronecap, b.npl, b.cash, b.deposit, b.liq, b.llr, b.roa, b.rssd9348, b.rssd9364, b.zip_code, b.state_code
from delr_year as a left join call_7 as b
on a.rssd9001 = b.rssd9001 and a.year = b.year; 
quit;

data delr_year; set delr_year; by rssd9001 year;
lag_at=lag(asset); lag_lnat=lag(lnat); lag_tieronecap=lag(tieronecap); lag_delr_avg=lag(delr_avg); lag_alwn=lag(alwn);
if first.rssd9001 then do; 
lag_at=.;lag_tieronecap=.;lag_lnat=.;lag_delr_avg=.;lag_alwn=.;
end;
run;

**Create Z-score and asset volatility;
proc sql;
create table zscore_1 as select distinct a.*, b.roa, b.equity_to_asset, b.asset
from call_4 as a left join call_1 as b
on a.rssd9001 = b.rssd9001 and a.date = b.date;
quit;

data zscore_1; set zscore_1;
if rankdate>'30sep2000'd;
if roa ne .;
run;

proc sort data=zscore_1; by rssd9001 rankdate; quit; 

proc sql;
create table zscore_1 as
select *, max(i) as max_i
from zscore_1
group by rssd9001, rankdate;
quit;

data zscore_2; set zscore_1;
if max_i=12;
run;

proc means data=zscore_2 noprint; by rssd9001 rankdate; 
output out=zscore_2_mean 
mean(roa equity_to_asset asset)=roa_avg equity_to_asset_avg asset_avg std(roa asset)=roa_std asset_std;
quit; 

data zscore_2_mean; set zscore_2_mean;
zscore=(roa_avg+equity_to_asset_avg)/roa_std;
asset_vol=asset_std/asset_avg;
year=year(rankdate);
run;

proc means data=zscore_2_mean noprint; by rssd9001 year; 
output out=zscore_2_mean_year 
mean(zscore asset_vol)=zscore_year asset_vol_year;
quit; 

proc sort data=zscore_2_mean_year; by rssd9001 year; quit; 

proc sql;
create table delr_year as select a.*, b.zscore_year, b.asset_vol_year
from delr_year as a left join zscore_2_mean_year as b
on a.rssd9001 = b.rssd9001 and a.year = b.year; 
quit;

**Create the public bank indicator using the CRSP-FRB link table (20161231);  
data delr_call_1; set delr_year;
keep year rssd9001 rssd9348 rssd9364;
run;

proc sql;
create table delr_call_2 as select a.*, b.permco as permco1, b.dt_start as dt_start1, b.dt_end as dt_end1
from delr_call_1 as a left join dlr.link_crsp as b
on a.rssd9001 = b.entity; 
quit;

proc sql;
create table delr_call_2 as select a.*, b.permco as permco2, b.dt_start as dt_start2, b.dt_end as dt_end2
from delr_call_2 as a left join dlr.link_crsp as b
on a.rssd9348 = b.entity; 
quit;

proc sql;
create table delr_call_2 as select a.*, b.permco as permco3, b.dt_start as dt_start3, b.dt_end as dt_end3
from delr_call_2 as a left join dlr.link_crsp as b
on a.rssd9364 = b.entity; 
quit;

data delr_call_3; set delr_call_2;
permco=permco1;
dt_start=dt_start1;
dt_end=dt_end1;
run;

data delr_call_3; set delr_call_3;
if permco=. then permco=permco2;
if dt_start=. then dt_start=dt_start2;
if dt_end=. then dt_end=dt_end2;
run;

data delr_call_3; set delr_call_3;
if permco=. then permco=permco3;
if dt_start=. then dt_start=dt_start3;
if dt_end=. then dt_end=dt_end3;
run;

proc sql;
create table delr_call_5 as select a.*, b.permco, b.dt_start, b.dt_end
from delr_year as a left join delr_call_3 as b
on a.year = b.year and a.rssd9001 = b.rssd9001; 
quit;

proc sort data=delr_call_5 out=delr_call_5 nodupkey;
by rssd9001 year;
run;

data delr_call_5 (drop= permco dt_start dt_end year_start year_end); set delr_call_5;
year_start=floor(dt_start/10000);
year_end=floor(dt_end/10000);
if permco~=. and year >= year_start and year <= year_end then public=1; else public=0;
run;

proc sort data=delr_call_5 out=delr_call_5 nodupkey;
by rssd9001 year;
run;

*Create Distance from the SEC offices;
data distance_1; set delr_call_5;
run;
data distance_1; set distance_1;
keep rssd9001 year zip_code d1-d6;
DC=20549;Chicago=60604;Denver=80294;Los_Angeles=90071;Miami=33131;New_York=10281;
d1=zipcitydistance(zip_code,DC);
d2=zipcitydistance(zip_code,Chicago);
d3=zipcitydistance(zip_code,Denver);
d4=zipcitydistance(zip_code,Los_Angeles);
d5=zipcitydistance(zip_code,Miami);
d6=zipcitydistance(zip_code,New_York);
run;

**Take the minimum distance for each bank;
data distance_1; set distance_1;
d_min=min(of d1-d6);
run;

proc sql;
create table delr_call_5 as select a.*, b.d_min
from delr_call_5 as a left join distance_1 as b
on a.rssd9001 = b.rssd9001 and a.year = b.year; 
quit;

*Create post and pre variables;
proc sort data=delr_call_5;
by rssd9001 year;
run;

data delr_call_post; set delr_call_5;
if year<2007 or year>2010 then delete;
run;

proc means data=delr_call_post noprint; by rssd9001; 
output out=delr_post 
mean(lnat tieronecap npl cash deposit liq llr roa)=lnat_post tieronecap_post npl_post cash_post deposit_post liq_post llr_post roa_post;
quit; 

proc sql;
create table delr_call_5 as select a.*, b.lnat_post, b.tieronecap_post, b.npl_post, b.cash_post, 
b.deposit_post, b.liq_post, b.llr_post, b.roa_post
from delr_call_5 as a left join delr_post as b
on a.rssd9001 = b.rssd9001; 
quit;

data delr_call_pre; set delr_call_5;
if year<2004 or year>2006 then delete;
run;

proc means data=delr_call_pre noprint; by rssd9001; 
output out=delr_pre 
mean(delr_avg alwn lnat tieronecap npl cash deposit liq llr roa zscore_year asset_vol_year)=
delr_pre alwn_pre lnat_pre tieronecap_pre npl_pre cash_pre deposit_pre liq_pre llr_pre roa_pre zscore_pre asset_vol_pre;
quit; 

proc sql;
create table delr_call_5 as select a.*, b.delr_pre, b.alwn_pre, b.lnat_pre, b.tieronecap_pre, b.npl_pre, b.cash_pre, 
b.deposit_pre, b.liq_pre, b.llr_pre, b.roa_pre, b.zscore_pre, b.asset_vol_pre
from delr_call_5 as a left join delr_pre as b
on a.rssd9001 = b.rssd9001; 
quit;

*Delete observations without key variables;
data delr_call_5; set delr_call_5;
if delr_pre=. then delete;
if lnat=. then delete;
if cash=. then delete;
if deposit=. then delete;
if lag_tieronecap=. then delete;
if liq=. then delete;
if llr=. then delete;
if npl=. then delete;
if roa=. then delete;
run;

*Save to the main folder;
data dlr.delr_call; set delr_call_5;
run;



