ods graphics off;

*Designate library names for data folders;
libname hmda "D:\Data\HMDA"; /*folder for the HMDA data*/
libname dlr "C:\Dropbox\Securitization\Submission\JAR - Final"; /*folder for the main folder for the project*/

*import Dataquick transaction data;
data transact_2; set dlr.transact;
if sr_property_id=. then delete;
if sr_tran_type in ('S','R');
if sr_arms_length_flag='1';
if mm_fips_state_code=. or mm_fips_state_code=2 or mm_fips_state_code=15 or mm_fips_state_code=66 or mm_fips_state_code=69 or mm_fips_state_code=72 or mm_fips_state_code=78 then delete;
year=year(sr_date_transfer);
if year(sr_date_transfer) < 2004 or year(sr_date_transfer) > 2010 then delete;
run;

*Combine the transaction data with the assess data;
proc sql;
create table transact_2 as select a.*, b.sa_property_id, b.sa_site_zip
from transact_2 as a left join dlr.assess as b
on a.sr_property_id = b.sa_property_id; 
quit;

*Delete observations without property id and ZIP-code id;
data transact_3; set transact_2;
if sa_property_id=. or sa_site_zip=. or sr_unique_id=. then delete;
if sa_site_zip=0 then delete;
run;

*Keep the most recent observation for each property and date;
proc sort data=transact_3 out=cleaned_1a nodupkey;
by sa_property_id sr_date_transfer descending sr_val_transfer;
run;

*Create indicators for distressed sales;
data cleaned_1a; set cleaned_1a; 
if distress_indicator in ('A','I','S') then dist_all=1; else dist_all=0;
if distress_indicator = 'I' then shortsale=1; else shortsale=0;
if distress_indicator in ('A','S') then foreclosure=1; else foreclosure=0;
run;

*Compute the number of total properties and distressed sales by ZIP-code and year;
proc sql;
create table cleaned_2 as
select *, count(sr_unique_id) as num_tran, sum(dist_all) as num_dist_all, sum(shortsale) as num_shortsale, 
sum(foreclosure) as num_foreclosure
from cleaned_1a
group by year, sa_site_zip;
quit;

*Keep only one observation by ZIP-code and year;
proc sort data=cleaned_2 out=cleaned_3 nodupkey;
by sa_site_zip year;
run;

*Compute distressed-sales rates;
data dlr.foreclosure_my(keep=sa_site_zip year dist_rate shortsale_rate foreclosure_rate); set cleaned_3; 
dist_rate = num_dist_all/num_tran;
shortsale_rate = num_shortsale/num_tran;
foreclosure_rate = num_foreclosure/num_tran;
run;
