ods graphics off;

*Designate library names for data folders;
libname hmda "D:\Data\HMDA"; /*folder for the HMDA data*/
libname dlr "C:\Dropbox\Securitization\Submission\JAR - Final"; /*folder for the main folder for the project*/

*Import the HMDA data of 2004 - 2010;
data hmda_2(drop=ethnic_co race2-race5 race_co1-race_co5 sex_co denial1-denial3 spread edit VAR38_ popul minority
med_income income_pct ownerunit familyunit date preapprove hoepa); set hmda.hmda_2004-hmda.hmda_2010; 
if state=. or state=2 or state=15 or state=66 or state=69 or state=72 or state=78 then delete;
if action=. or MSA="" or county="" or race1=. or loantype=. or propertytype=. or lien=. or sex=. or ethnic=. or occupancy=. then delete; 
if action=1;
if amount <=1 then delete;
if income <=10 then delete;
if loanpurpose in (1,3);
if loantype in (1,2);
if loantype=1 then conventional=1; else conventional=0;
if loantype=2 then fha=1; else fha=0;
if purchaser=0 then sold=0; else sold=1;
if propertytype=1 ;
if agency=7 then nonbank=1; else nonbank=0;
census_tract=tract*100;
state_new = put(state,2.);
fips1 = cat(state_new,county); 
fips_code = fips1*1;
drop fips1 state_new;
run;

*Import the HMDA data of 2001 - 2003 (This step is necessary because formats of several variables became different since 2004);
data hmda_2pre(drop=ethnic_co race2-race5 race_co1-race_co5 sex_co denial1-denial3 spread edit VAR38_); set hmda.hmda_2001-hmda.hmda_2003; 
if state=. or state=2 or state=15 or state=66 or state=69 or state=72 or state=78 then delete;
if action=. or MSA="" or county="" or race1=. or loantype=. or sex=. then delete; 
if action=1;
if amount <=1 then delete;
if income <=10 then delete;
if loanpurpose in (1,3);
if loantype in (1,2);
if loantype=1 then conventional=1; else conventional=0;
if loantype=2 then fha=1; else fha=0;
if purchaser=0 then sold=0; else sold=1;
if agency=7 then nonbank=1; else nonbank=0;
census_tract=tract*100;
state_new = put(state,2.);
fips1 = cat(state_new,county); 
fips_code = fips1*1;
drop fips1 state_new;
run;

*Combine two HMDA data sets;
data hmda_2; set hmda_2pre hmda_2; 
run;

*Import the link file between census tracts to ZIP codes;
proc sql;
create table hmda_2a as select a.*, b.zcta5
from hmda_2 as a left join dlr.link_zip1 as b
on a.fips_code = b.fips_code and a.census_tract = b.tract; 
quit;

*Delete observations with missing ZIP code identifiers;
data hmda_2a; set hmda_2a; 
if zcta5=. then delete;
run;

*Import thresholds for jumbo loans by county and year;
proc sql;
create table hmda_2a as select a.*, b.one as one_1
from hmda_2a as a left join dlr.jumbo_2009_2016 as b
on a.year = b.year and a.fips_code = b.fips_code; 
quit;

proc sql;
create table hmda_2a as select a.*, b.one as one_2
from hmda_2a as a left join dlr.jumbo_2007_2008 as b
on a.year = b.year and a.fips_code = b.fips_code; 
quit;

proc sql;
create table hmda_2a as select a.*, b.one as one_3
from hmda_2a as a left join dlr.jumbo_1980_2007 as b
on a.year = b.year; 
quit;

**Create the jumbo loan indicator using the threshold;
data hmda_2a; set hmda_2a;
if one_2=. then one_2=one_3;
run;

data hmda_2a (drop=one_2 one_3); set hmda_2a;
if one_1=. then one_1=one_2;
run;

data hmda_2a; set hmda_2a;
if loantype=1 and amount>one_1 then jumbo=1; else jumbo=0;
if loantype=1 and amount<=one_1 then nonjumbo=1; else nonjumbo=0;
run;

*Import the link file between Call Reports and HMDA using the reporter panel; 
proc sql;
create table hmda_2a as select a.*, b.respondent_rssd_id
from hmda_2a as a left join hmda.hmda_reporter_nac as b
on a.bankid = b.respondent_id and a.agency = b.agency_code and a.year = b.year; 
quit;

**Using 2004 infomation in the link file for years before 2004;
data hmda_reporter_nac; set hmda.hmda_reporter_nac; 
if year=2004;
run;

proc sql;
create table hmda_2a as select a.*, b.respondent_rssd_id as r_id
from hmda_2a as a left join hmda_reporter_nac as b
on a.bankid = b.respondent_id and a.agency = b.agency_code; 
quit;

data hmda_2a (drop=r_id); set hmda_2a; 
if year<2004 then respondent_rssd_id=r_id;
run;

*Import bank-level variables and link them to the HMDA data;
proc sql;
create table hmda_2a as select a.*, b.rssd9001 as mergeid, b.delr_avg as delr_current, b.lag_delr_avg as lag_delr_current, b.delr_pre, b.delr_2006, 
b.alwn, b.alwn_pre, b.lag_alwn, b.alwn_2006, b.asset, b.lag_at, b.lag_lnat, b.lnat, b.lag_tieronecap,
b.npl, b.cash, b.deposit, b.liq, b.llr, b.roa, b.public, b.d_min, b.zscore_year, b.asset_vol_year, b.zscore_pre, b.asset_vol_pre
from hmda_2a as a left join dlr.delr_call as b
on a.year = b.year and a.respondent_rssd_id = b.rssd9001; 
quit;

*Delete observations without bank identifiers to construct bank-level variables during the pre-period;
data hmda_2b; set hmda_2a;
drop respondent_rssd_id;
if mergeid=. or mergeid=0 then delete;
run;

**Keep only one observation for each bank;
proc sort data=hmda_2b out=estimates_pre nodupkey;
by mergeid;
run;

data estimates_pre; set estimates_pre;
keep mergeid delr_pre delr_2006 alwn_pre alwn_2006 zscore_pre asset_vol_pre _TYPE_;
_TYPE_=0;
run;

**Compute median values by bank during the pre-period;
proc means data=estimates_pre noprint;
output out=delr_pre 
p50(delr_pre delr_2006 alwn_pre alwn_2006 zscore_pre asset_vol_pre)=delr_pre_med delr_2006_med alwn_pre_med alwn_2006_med zscore_pre_med asset_vol_pre_med;
quit; 

proc sql;
create table delr_pre as select a.*, b.delr_pre_med, b.delr_2006_med, b.alwn_pre_med, b.alwn_2006_med, b.zscore_pre_med, b.asset_vol_pre_med 
from estimates_pre as a left join delr_pre as b
on a._TYPE_=b._TYPE_; 
quit;

**Create high-DLRs, high-ALWN, high-Zscore, and high-asset-volatility indicators;
data delr_pre; set delr_pre;
if delr_pre>delr_pre_med then delr_h=1; else delr_h=0;
if delr_2006>delr_2006_med then delr_h_2006=1; else delr_h_2006=0;
if alwn_pre>alwn_pre_med then alwn_h=1; else alwn_h=0;
if alwn_2006>alwn_2006_med then alwn_h_2006=1; else alwn_h_2006=0;
if zscore_pre>zscore_pre_med then zscore_h=1; else zscore_h=0;
if asset_vol_pre>asset_vol_pre_med then asset_vol_h=1; else asset_vol_h=0;
run;

data dlr.delr_pre; set delr_pre;
run;

**Combine those indicators with the HMDA data;
proc sql;
create table hmda_2a as select a.*, b.delr_h as delr_h_bank, b.delr_h_2006 as delr_h_bank_2006,
b.alwn_h as alwn_h_bank, b.alwn_h_2006 as alwn_h_bank_2006, b.zscore_h as zscore_h_bank, b.asset_vol_h as asset_vol_h_bank
from hmda_2a as a left join delr_pre as b
on a.respondent_rssd_id = b.mergeid; 
quit;

*Create low-DLR bank indicator;
data hmda_2a; set hmda_2a;
if delr_h_bank = 0 then delr_l_bank = 1; else delr_l_bank = 0;
run;

*Compute mortgages issued by all, high-DLR banks, low-DLR banks, and nonbanks by ZIP-code and year;
proc sql;
create table hmda_3 as
select *, sum(amount) as amount_zip, sum(amount*delr_h_bank) as amount_zip_delr_h, sum(amount*delr_l_bank) as amount_zip_delr_l,
sum(amount*nonbank) as amount_zip_nonbank
from hmda_2a
group by year, zcta5;
quit;

*Compute mortgages issued by year;
proc sql;
create table hmda_3 as
select *, sum(amount) as amount_year
from hmda_3
group by year;
quit;

*Compute mortgages issued by ZIP-code, bank, and year for different types of mortgages;
proc sql;
create table hmda_4 as
select *, sum(amount) as amount_ins, sum(amount*conventional) as conven_ins, sum(amount*jumbo*conventional) as jumbo_ins,
sum(amount*nonjumbo*conventional) as nonjumbo_ins, sum(amount*fha) as fha_ins
from hmda_3
group by year, zcta5, bankid;
quit;

*Compute mortgages issued by bank and year for different types of mortgages, also compute Off-Balance-Sheet Rate;
proc sql;
create table hmda_4 as
select *, sum(amount) as amount_ins_all, sum(amount*conventional) as conven_ins_all, sum(amount*jumbo*conventional) as jumbo_ins_all,
sum(amount*nonjumbo*conventional) as nonjumbo_ins_all, sum(amount*fha) as fha_ins_all, mean(sold) as off_bs_rate
from hmda_4
group by year, bankid;
quit;

*Keep only one observation for each ZIP-code, bank, year;
proc sort data=hmda_4 out=hmda_5 nodupkey;
by year zcta5 bankid;
run;

*Compute market shares;
data hmda_5; set hmda_5; 
marketshare=amount_ins/amount_zip;
marketshare_all=amount_ins_all/amount_year;
marketshare_ins=amount_ins/amount_ins_all;
run;

*Compute HHI by ZIP-code and yar;
proc sql;
create table hmda_5 as
select *, sum(marketshare**2) as hhi
from hmda_5
group by year, zcta5;
quit;

*Compute Top-3 mortgage markets for each bank;
proc sort data=hmda_5;
by year bankid descending marketshare_ins;
run;

data hmda_5; set hmda_5;
by year bankid;
seq_zip+1;
if first.bankid then seq_zip=1;
run;

data hmda_5; set hmda_5;
if seq_zip=1 then major_zip=0; else major_zip=1;
if seq_zip=1 or seq_zip=2 or seq_zip=3 then major_zip3=0; else major_zip3=1;
run;

*Compute big 4 market shares and number of lenders by ZIP-code and year;
proc sort data=hmda_5;
by year zcta5 descending marketshare;
run;
data hmda_6; set hmda_5;
by year zcta5;
retain counter big4 .;
if first.zcta5 then do; 
big4 = 0;
counter = 1;
end;
if counter le 4 then do;
big4 = sum(big4,marketshare);
end;
if last.year or last.zcta5 then do;
output;
end;
counter = counter+1;
run;

**Combine big4 market shares and number of lenders with the HMDA data;
proc sql;
create table hmda_7 as select a.*, b.big4, b.counter as no_lender
from hmda_5 as a left join hmda_6 as b
on a.year = b.year and a.zcta5 = b.zcta5; 
quit;

*Compute Nonbank Shares by ZIP-code and year; 
proc sql;
create table hmda_7 as
select *, sum(marketshare*nonbank) as nonbank_share
from hmda_7
group by year, zcta5;
quit;

*Compute market shares of each bank and public banks by ZIP-code and year; 
proc sql;
create table hmda_7 as
select *, sum(amount_ins) as amount_zip_bank, sum(amount_ins*public) as amount_zip_public
from hmda_7
group by year, zcta5;
quit;

*Drop variables not necessary for the analysis;
data hmda_7; set hmda_7;
drop agency loantype loanpurpose occupancy amount action sex income purchaser propertytype preapprove 
ethnic race1 hoepa lien popul minority med_income income_pct ownerunit familyunit date conventional fha approve 
one_1 jumbo nonjumbo respondent_rssd_id marketshare_all;
run;

*Combine regional characteristics with the HMDA Data;
**Employment and Business Establishements from CBP;
proc sql;
create table hmda_8 as select a.*, b.g_emp, b.g_est
from hmda_7 as a left join dlr.cbp as b
on a.zcta5 = b.zipcode and a.year = b.year; 
quit;
**Income growth and average income from IRS;
proc sql;
create table hmda_8 as select a.*, b.g_gross_income, b.avg_income
from hmda_8 as a left join dlr.irs_all as b
on a.zcta5 = b.zipcode and a.year = b.year; 
quit;

***Fill in missing 2003 income with 2004 income;
data hmda_8; set hmda_8;
if year=2004 then g_gross_income_04=g_gross_income;
if year=2004 then avg_income_04=avg_income;
run;

proc sql;
create table hmda_8 as
select *, 
max(g_gross_income_04) as g_gross_income_max, max(avg_income_04) as avg_income_max 
from hmda_8
group by zcta5;
quit;

data hmda_8 (drop=g_gross_income_04 avg_income_04 g_gross_income_max avg_income_max); set hmda_8;
if year=2003 then g_gross_income=g_gross_income_max;
if year=2003 then avg_income=avg_income_max;
run;

**Demographics, poverty, and education data are from Census;
proc sql;
create table hmda_8 as select a.*, b.*
from hmda_8 as a left join dlr.census_zip as b
on a.zcta5 = b.zip_code; 
quit;

*Create bank-level data;
proc sort data=hmda_8 out=hmda_8b nodupkey;
by mergeid year;
run;

data hmda_8b; set hmda_8b;
keep year mergeid bankid delr_pre delr_current delr_h_bank alwn_pre alwn lnat asset lag_at lag_lnat cash deposit lag_tieronecap liq llr npl roa amount_ins_all off_bs_rate
zscore_h_bank asset_vol_h_bank zscore_year zscore_pre asset_vol_year asset_vol_pre;
if year<2004 then delete;
if year>2010 then delete;
if delr_pre=. then delete;
if delr_h_bank=. then delete;
if lnat=. then delete;
if cash=. then delete;
if deposit=. then delete;
if lag_tieronecap=. then delete;
if liq=. then delete;
if llr=. then delete;
if npl=. then delete;
if roa=. then delete;
if off_bs_rate=. then delete;
run;

*Macro to winsorize variables;
%include 'C:\Dropbox\Securitization\Data_and_Code\macro_winsor.sas';
%winsor(dsetin=hmda_8b, dsetout=hmda_8b_out, byvar=none, 
vars= lnat asset cash deposit delr_pre delr_current alwn_pre alwn lag_tieronecap lag_at lag_lnat liq llr npl roa amount_ins_all off_bs_rate
zscore_year zscore_pre asset_vol_year asset_vol_pre, type=winsor, pctl=1 99);

PROC EXPORT DATA= WORK.hmda_8b 
            OUTFILE= "C:\Dropbox\Securitization\Submission\JAR - Final\delr_bank.dta" 
            DBMS=STATA REPLACE;
RUN;

*Create public bank market share at the ZIP-code level;
data hmda_9; set hmda_8; 
ms_public=amount_zip_public/amount_zip;
run;

*Create ZIP-code level variables involving bank-level charatersitics based on market share of each bank; 
proc sql;
create table hmda_10 as
select *, sum(marketshare*delr_current) as ms_h, sum(marketshare*major_zip3*delr_current) as ms_h_nomajor3, sum(marketshare*alwn) as alwn_zip,
sum(marketshare*lag_tieronecap) as lag_tieronecap_zip, sum(marketshare*delr_2006) as ms_2006,
sum(marketshare*lnat) as lnat_zip,
sum(marketshare*cash) as cash_zip,
sum(marketshare*deposit) as deposit_zip,
sum(marketshare*liq) as liq_zip,
sum(marketshare*llr) as llr_zip,
sum(marketshare*npl) as npl_zip,
sum(marketshare*roa) as roa_zip,
sum(marketshare*off_bs_rate) as off_bs_rate_zip,
sum(-1*marketshare*log(d_min)*public) as iv_sec,
sum(marketshare*public) as iv_public, sum(marketshare*lag_delr_current) as lag_ms_h, sum(marketshare*lag_alwn) as lag_alwn_zip,
sum(marketshare*zscore_year) as zscore_zip, sum(marketshare*asset_vol_year) as asset_vol_zip
from hmda_9
group by year, zcta5;
quit;

*Keep only one observation for each ZIP code and year;
proc sort data=hmda_10 nodupkey;
by zcta5 year;
run;

*Import two housing price indexes;
proc sql;
create table hmda_10 as select a.*, b.hpi as price1, b.d_hpi as d_price1
from hmda_10 as a left join dlr.hpi_fhfa_zip as b
on a.year = b.year and a.zcta5 = b.zip; 
quit;
proc sql;
create table hmda_10 as select a.*, b.HOME_PRICE_INDEX as price2, b.d_price2
from hmda_10 as a left join dlr.hpi_core_zip_2 as b
on a.year = b.year and a.zcta5 = b.zip_code; 
quit;

*Delete observations without ?logHPI - FHFA and the ZIP-code level Exposure measure;
data hmda_10; set hmda_10; 
if d_price1=. then delete;
if ms_h=. then delete;
run;

*Import distressed sales measures from the DataQuick data; 
proc sql;
create table hmda_10 as select a.*, b.dist_rate, b.shortsale_rate, b.foreclosure_rate
from hmda_10 as a left join dlr.foreclosure_my as b
on a.zcta5 = b.sa_site_zip and a.year = b.year; 
quit;

proc sort data=hmda_10;
by zcta5 year;
run;

*Create logCredit and ?logCredit variables;
data hmda_11; set hmda_10; by zcta5 year;
lag_amount_zip=lag(amount_zip); lag_amount_zip_delr_h=lag(amount_zip_delr_h); lag_amount_zip_delr_l=lag(amount_zip_delr_l);
lag_amount_zip_nonbank=lag(amount_zip_nonbank);
if first.zcta5 then do; 
lag_amount_zip=.; lag_amount_zip_delr_h=.; lag_amount_zip_delr_l=.;lag_amount_zip_nonbank=.;
end;
run;

data hmda_11; set hmda_11;
d_amt_zip=log(amount_zip)-log(lag_amount_zip);
d_amt_zip_h=log(amount_zip_delr_h)-log(lag_amount_zip_delr_h);
d_amt_zip_l=log(amount_zip_delr_l)-log(lag_amount_zip_delr_l);
d_amt_zip_nonbank=log(amount_zip_nonbank)-log(lag_amount_zip_nonbank);
run;

proc sort data=hmda_11 out=hmda_12;
by zcta5 year;
run;

data hmda_12; set hmda_12;
ln_avg_income = log(avg_income);
ln_pop = log(total_population);
ln_amount_zip=log(amount_zip);
run;

*Create Exposure High variable;
data region; set hmda_12;
keep zcta5 year ms_h ms_h_rob ms_h_rob2 ms_h_nomajor3 alwn_zip dist_rate shortsale_rate foreclosure_rate lag_tieronecap_zip iv_sec iv_public g_emp g_est g_gross_income
avg_income ln_avg_income ms_public hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip;
run;

proc sort data=region;
by zcta5 year;
run;

proc means data=region noprint; by zcta5; 
output out=region_avg 
mean(lag_tieronecap_zip g_emp g_est g_gross_income avg_income ln_avg_income ms_public hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip)
=lag_tieronecap_zip_avg g_emp_avg g_est_avg g_gross_income_avg avg_income_avg ln_avg_income_avg ms_public_avg
hhi_avg nonbank_share_avg d_amt_zip_nonbank_avg zscore_zip_avg asset_vol_zip_avg;
quit; 

data region_pre; set hmda_12;
keep zcta5 year ms_h ms_h_nomajor3 alwn_zip dist_rate shortsale_rate foreclosure_rate lag_tieronecap_zip iv_sec iv_public g_emp g_est g_gross_income 
avg_income ln_avg_income ms_public hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip;
if year<2004 or year>2006 then delete;
run;

proc sort data=region_pre;
by zcta5 year;
run;

proc means data=region_pre noprint; by zcta5; 
output out=ms_pre 
mean(ms_h ms_h_nomajor3 alwn_zip iv_sec iv_public dist_rate shortsale_rate foreclosure_rate
lag_tieronecap_zip g_emp g_est g_gross_income avg_income ln_avg_income ms_public hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip)
=ms_h_pre ms_h_nomajor3_pre alwn_zip_pre iv_sec_pre iv_public_pre dist_rate_pre shortsale_rate_pre foreclosure_rate_pre lag_tieronecap_zip_pre g_emp_pre g_est_pre 
g_gross_income_pre avg_income_pre ln_avg_income_pre ms_public_pre hhi_pre nonbank_share_pre d_amt_zip_nonbank_pre zscore_zip_pre asset_vol_zip_pre;
quit; 

proc means data=ms_pre noprint;
output out=ms_pre2 
p50(ms_h_pre)=ms_h_pre_med 
p50(ms_h_nomajor3_pre)=ms_h_nomajor3_pre_med 
p50(alwn_zip_pre)=alwn_zip_pre_med 
p50(zscore_zip_pre)=zscore_zip_pre_med
p50(asset_vol_zip_pre)=asset_vol_zip_pre_med;
quit; 
proc sql;
create table ms_pre as select a.*, b.ms_h_pre_med, b.ms_h_nomajor3_pre_med, b.alwn_zip_pre_med, b.zscore_zip_pre_med, b.asset_vol_zip_pre_med
from ms_pre as a left join ms_pre2 as b
on a._TYPE_=b._TYPE_; 
quit;
data ms_pre; set ms_pre;
if ms_h_pre>ms_h_pre_med then delr_r_h=1; else delr_r_h=0;
if ms_h_nomajor3_pre>ms_h_nomajor3_pre_med then delr_r_h_nomajor3=1; else delr_r_h_nomajor3=0;
if alwn_zip_pre>alwn_zip_pre_med then alwn_zip_h=1; else alwn_zip_h=0;
if zscore_zip_pre>zscore_zip_pre_med then zscore_zip_h=1; else zscore_zip_h=0;
if asset_vol_zip_pre>asset_vol_zip_pre_med then asset_vol_zip_h=1; else asset_vol_zip_h=0;
run;

**Create post controls (2007-2010);
data region_post; set hmda_12;
keep zcta5 year dist_rate shortsale_rate foreclosure_rate lag_tieronecap_zip g_emp g_est g_gross_income avg_income ln_avg_income ms_public
hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip;
if year<2007 then delete;
run;

proc sort data=region_post;
by zcta5 year;
run;

proc means data=region_post noprint; by zcta5; 
output out=ms_post 
mean(dist_rate shortsale_rate foreclosure_rate lag_tieronecap_zip g_emp g_est g_gross_income avg_income ln_avg_income ms_public hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip)
=dist_rate_post shortsale_rate_post foreclosure_rate_post lag_tieronecap_zip_post g_emp_post g_est_post g_gross_income_post avg_income_post ln_avg_income_post 
ms_public_post hhi_post nonbank_share_post d_amt_zip_nonbank_post zscore_zip_post asset_vol_zip_post;
quit; 

*Create post controls (2007-2009);
data region_post2; set hmda_12;
keep zcta5 year dist_rate shortsale_rate foreclosure_rate lag_tieronecap_zip g_emp g_est g_gross_income avg_income ln_avg_income ms_public
hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip;
if year<2007 or year>2009 then delete;
run;

proc sort data=region_post2;
by zcta5 year;
run;

proc means data=region_post2 noprint; by zcta5; 
output out=ms_post2 
mean(dist_rate shortsale_rate foreclosure_rate lag_tieronecap_zip g_emp g_est g_gross_income avg_income ln_avg_income ms_public hhi nonbank_share d_amt_zip_nonbank zscore_zip asset_vol_zip)
=dist_rate_post2 shortsale_rate_post2 foreclosure_rate_post2 lag_tieronecap_zip_post2 g_emp_post2 g_est_post2 g_gross_income_post2 avg_income_post2 ln_avg_income_post2 
ms_public_post2 hhi_post2 nonbank_share_post2 d_amt_zip_nonbank_post2 zscore_zip_post2 asset_vol_zip_post2;
quit; 

*Combine with the ZIP-code level data;
proc sql;
create table hmda_12 as select a.*, b.delr_r_h, b.ms_h_pre, b.delr_r_h_nomajor3, b.ms_h_nomajor3_pre,
b.alwn_zip_h, b.alwn_zip_pre,
b.lag_tieronecap_zip_pre, b.iv_sec_pre, b.iv_public_pre, b.dist_rate_pre, b.shortsale_rate_pre, b.foreclosure_rate_pre,
b.g_emp_pre, b.g_est_pre, b.g_gross_income_pre, b.avg_income_pre, b.ln_avg_income_pre, b.ms_public_pre,
b.hhi_pre, b.nonbank_share_pre, b.d_amt_zip_nonbank_pre, b.zscore_zip_pre, b.asset_vol_zip_pre
from hmda_12 as a left join ms_pre as b
on a.zcta5 = b.zcta5; 
quit;

proc sql;
create table hmda_12 as select a.*, b.lag_tieronecap_zip_avg, b.g_emp_avg, b.g_est_avg, b.g_gross_income_avg, b.avg_income_avg, 
b.ln_avg_income_avg, b.ms_public_avg, b.hhi_avg, b.nonbank_share_avg, b.d_amt_zip_nonbank_avg, b.zscore_zip_avg, b.asset_vol_zip_avg
from hmda_12 as a left join region_avg as b
on a.zcta5 = b.zcta5; 
quit;

proc sql;
create table hmda_12 as select a.*, b.dist_rate_post, b.shortsale_rate_post, b.foreclosure_rate_post, b.lag_tieronecap_zip_post, 
b.g_emp_post, b.g_est_post, b.g_gross_income_post, b.avg_income_post, b.ln_avg_income_post, b.ms_public_post,
b.hhi_post, b.nonbank_share_post, b.d_amt_zip_nonbank_post, b.zscore_zip_post, b.asset_vol_zip_post
from hmda_12 as a left join ms_post as b
on a.zcta5 = b.zcta5; 
quit;

proc sql;
create table hmda_12 as select a.*, b.dist_rate_post2, b.shortsale_rate_post2, b.foreclosure_rate_post2, b.lag_tieronecap_zip_post2, 
b.g_emp_post2, b.g_est_post2, b.g_gross_income_post2, b.avg_income_post2, b.ln_avg_income_post2, b.ms_public_post2,
b.hhi_post2, b.nonbank_share_post2, b.d_amt_zip_nonbank_post2, b.zscore_zip_post2, b.asset_vol_zip_post2
from hmda_12 as a left join ms_post2 as b
on a.zcta5 = b.zcta5; 
quit;

*Import population at county level;
proc sort data=hmda.Zcta_county_rel_10 out=Zcta_county_rel_10 nodupkey;
by state county;
run;

data hmda_12; set hmda_12;
county1=county*1;
run;

proc sql;
create table hmda_12 as select a.*, b.copop
from hmda_12 as a left join Zcta_county_rel_10 as b
on a.state = b.state and a.county1 = b.county; 
quit;

proc sort data=hmda_12 out=county_pop nodupkey;
by fips_code;
run;

proc means data=county_pop noprint;
output out=county_pop_2 
p50(copop)=copop_med;
quit; 

data county_pop; set county_pop;
_TYPE_=0;
run;

proc sql;
create table county_pop as select a.*, b.copop_med
from county_pop as a left join county_pop_2 as b
on a._TYPE_=b._TYPE_; 
quit;
data county_pop; set county_pop;
if copop>copop_med then copop_high=1; else copop_high=0;
run;

proc sql;
create table hmda_12 as select a.*, b.copop_high
from hmda_12 as a left join county_pop as b
on a.fips_code = b.fips_code; 
quit;

*Delete observations with missing controls;
data hmda_13; set hmda_12;
drop sold nonbank mergeid delr_current lag_delr_current delr_pre delr_2006 alwn alwn_h_bank alwn_pre lag_alwn alwn_2006
asset lnat lag_tieronecap lag_at lag_lnat npl cash deposit liq llr roa state_chart public d_min l_index delr_h_bank
delr_l_bank delr_h_bank_2006 alwn_h_bank_2006 delr_l_bank ms_2006 m_h_2006 a_zip_2006 county1;
if year<2004 then delete;
if ms_h_pre=. then delete;
if lag_tieronecap_zip=. then delete;
if g_emp=. then delete;
if g_est=. then delete;
if g_gross_income=. then delete;
if avg_income=. then delete;
if hhi=. then delete;
if nonbank_share=. then delete;
if d_amt_zip_nonbank=. then delete;
if ln_avg_income=. then delete;
if ln_pop=. then delete;
if ln_amount_zip=. then delete;
if off_bs_rate_zip=. then delete;
run;

proc sort data=hmda_13;
by zcta5 year;
run;

data dlr.hmda_13; set hmda_13;
run;

*Macro to winsorize variables;
%include 'C:\Dropbox\Securitization\Data_and_Code\macro_winsor.sas';
%winsor(dsetin=hmda_13, dsetout=hmda_out, byvar=none, 
vars=lag_tieronecap_zip price1 price2 d_price1 d_price2 amount_zip amount_zip_delr_h amount_zip_delr_l d_amt_zip d_amt_zip_h d_amt_zip_l d_amt_zip_nonbank 
g_emp g_est g_gross_income avg_income hhi nonbank_share ln_avg_income ln_pop ln_amount_zip 
total_population black_population_pct hispanic_population_pct highschool_higher_pct bachelor_higher_pct poverty_pct unemployment_rate ms_public iv_public 
ms_h ms_h_nomajor3 alwn_zip lag_ms_h lag_alwn_zip 
ms_h_pre ms_h_nomajor3_pre alwn_zip_pre iv_sec_pre iv_public_pre dist_rate_pre shortsale_rate_pre foreclosure_rate_pre 
lag_tieronecap_zip_pre g_emp_pre g_est_pre g_gross_income_pre avg_income_pre ln_avg_income_pre hhi_pre nonbank_share_pre d_amt_zip_nonbank_pre zscore_zip_pre asset_vol_zip_pre
lag_tieronecap_zip_avg g_emp_avg g_est_avg g_gross_income_avg avg_income_avg ln_avg_income_avg ms_public_avg 
hhi_avg nonbank_share_avg d_amt_zip_nonbank_avg zscore_zip_avg asset_vol_zip_avg
dist_rate_post shortsale_rate_post foreclosure_rate_post lag_tieronecap_zip_post g_emp_post g_est_post g_gross_income_post avg_income_post ln_avg_income_post 
ms_public_post hhi_post nonbank_share_post d_amt_zip_nonbank_post 
dist_rate_post2 shortsale_rate_post2 foreclosure_rate_post2 lag_tieronecap_zip_post2 g_emp_post2 g_est_post2 g_gross_income_post2 avg_income_post2 ln_avg_income_post2 
ms_public_post2 hhi_post2 nonbank_share_post2 d_amt_zip_nonbank_post2 zscore_zip_post2 asset_vol_zip_post2
dist_rate shortsale_rate foreclosure_rate
lnat_zip cash_zip deposit_zip liq_zip llr_zip npl_zip roa_zip off_bs_rate_zip zscore_zip asset_vol_zip, type=winsor, pctl=1 99);

*Export the ZIP-code-level data in STATA format;
PROC EXPORT DATA= WORK.hmda_out 
            OUTFILE= "C:\Dropbox\Securitization\Submission\JAR - Final\delr_zip_r.dta" 
            DBMS=STATA REPLACE;
RUN;

/*Starting from here, I create bank-ZIP-code-level data.*/
*Keep only one observation for each bank. ZIP-code, and year;
proc sort data=hmda_8 out=hmda_8c nodupkey;
by zcta5 mergeid year;
run;

*Combine ZIP-code-level data with bank-ZIP-code-level data;
proc sql;
create table hmda_8c as select a.*, b.lag_tieronecap_zip, b.hhi, b.nonbank_share, b.d_amt_zip_nonbank, b.ln_avg_income, b.ln_pop,
b.ln_amount_zip, b.ms_public, b.lag_amount_zip 
from hmda_8c as a left join hmda_13 as b
on a.zcta5 = b.zcta5 and a.year = b.year; 
quit;

*Create regression variables;
data hmda_8c; set hmda_8c;
_TYPE_=0;
ln_amount_ins=log(amount_ins);
amount_ins_ms=amount_ins/amount_zip*100;
log_d_min = log(d_min);
iv_bank = -1*log(d_min)*public;
run;

*Create Intrumental Variable;
data hmda_8c_pre; set hmda_8c;
if year=2004 or year=2005 or year=2006;
run;
proc sort data=hmda_8c_pre out=hmda_8c_pre nodupkey;
by mergeid year;
run;

proc means data=hmda_8c_pre noprint; by mergeid; 
output out=hmda_8c_pre2 
mean(iv_bank)=iv_bank_pre;
quit; 

proc sql;
create table hmda_8c as select a.*, b.iv_bank_pre
from hmda_8c as a left join hmda_8c_pre2 as b
on a.mergeid = b.mergeid; 
quit;

*Delete observations with missing controls;
data hmda_8c; set hmda_8c;
if year<2004 then delete;
if year>2009 then delete;
if amount_ins_ms=. then delete;
if delr_pre=. then delete;
if delr_h_bank=. then delete;
if lnat=. then delete;
if cash=. then delete;
if deposit=. then delete;
if lag_tieronecap=. then delete;
if liq=. then delete;
if llr=. then delete;
if npl=. then delete;
if roa=. then delete;
if off_bs_rate=. then delete;
if lag_tieronecap_zip=. then delete;
if g_emp=. then delete;
if g_est=. then delete;
if g_gross_income=. then delete;
if avg_income=. then delete;
if hhi=. then delete;
if nonbank_share=. then delete;
if d_amt_zip_nonbank=. then delete;
if ln_avg_income=. then delete;
if ln_pop=. then delete;
if ln_amount_zip=. then delete;
if black_population_pct=. then delete;
if hispanic_population_pct=. then delete;
if poverty_pct=. then delete;
if bachelor_higher_pct=. then delete;
run;

*Create High Cap1 and High ALWN variables;
proc sort data=hmda_8c out=hmda_8c2 nodupkey;
by year mergeid;
run; 

proc means data=hmda_8c2 noprint;
output out=hmda_8c3 
p50(lag_tieronecap lag_at lag_lnat lag_alwn)=lag_tieronecap_med lag_at_med lag_lnat_med lag_alwn_med;
by year;
quit; 

proc sql;
create table hmda_8c as select a.*, b.lag_tieronecap_med, b.lag_at_med, b.lag_lnat_med, b.lag_alwn_med 
from hmda_8c as a left join hmda_8c3 as b
on a.year=b.year; 
quit;

data hmda_8c (drop=lag_tieronecap_med lag_lnat_med lag_alwn_med); set hmda_8c;
if lag_tieronecap>lag_tieronecap_med then lag_tieronecap_h=1; else lag_tieronecap_h=0;
if lag_at>lag_at_med then lag_at_h=1; else lag_at_h=0;
if lag_lnat>lag_lnat_med then lag_lnat_h=1; else lag_lnat_h=0;
if lag_alwn>lag_alwn_med then lag_alwn_h=1; else lag_alwn_h=0;
run;

*Macro to winsorize variables;
%include 'C:\Dropbox\Securitization\Data_and_Code\macro_winsor.sas';
%winsor(dsetin=hmda_8c, dsetout=hmda_8c_out, byvar=none, 
vars=delr_current lag_delr_current delr_pre delr_2006 alwn lag_alwn alwn_2006
asset lnat lag_tieronecap lag_at lag_lnat npl cash deposit liq llr roa off_bs_rate ln_amount_ins amount_ins_ms
lag_tieronecap_zip amount_zip d_amt_zip_nonbank g_emp g_est g_gross_income avg_income hhi nonbank_share ln_avg_income ln_pop ln_amount_zip 
total_population black_population_pct hispanic_population_pct highschool_higher_pct bachelor_higher_pct poverty_pct unemployment_rate ms_public iv_bank iv_bank_pre d_min 
zscore_year zscore_pre asset_vol_year asset_vol_pre
, type=winsor, pctl=1 99);

*Export the ZIP-code-level data in STATA format;
PROC EXPORT DATA= WORK.hmda_8c_out
            OUTFILE= "C:\Dropbox\Securitization\Submission\JAR - Final\delr_zip_bank.dta" 
            DBMS=STATA REPLACE;
RUN;

proc datasets library=work kill nolist;
quit;


/*Starting from here, I create application-level data.*/
*Import the HMDA data of 2004 - 2010;
data hmda_2(drop=ethnic_co race2-race5 race_co1-race_co5 sex_co denial1-denial3 spread edit VAR38_ popul minority
med_income income_pct ownerunit familyunit date); set hmda.hmda_2004-hmda.hmda_2010; 
if state=. or state=2 or state=15 or state=66 or state=69 or state=72 or state=78 then delete;
if action=. or MSA="" or county="" or race1=. or loantype=. or propertytype=. or lien=. or sex=. or ethnic=. or occupancy=. then delete; 
if amount <=1 then delete;
if income <=10 then delete;
if loanpurpose in (1,3);
if agency=7 then nonbank=1; else nonbank=0;
if loantype in (1,2);
if loantype=1 then conventional=1; else conventional=0;
if loantype=2 then fha=1; else fha=0;
if purchaser=0 then sold=0; else sold=1;
if action in (1,2) then approve=1; if action in (3) then approve=0; if approve=. then delete;
if propertytype=1 ;
census_tract=tract*100;
state_new = put(state,2.);
fips1 = cat(state_new,county); 
fips_code = fips1*1;
drop fips1 state_new;
run;

*Import the link file between census tracts to ZIP codes;
proc sql;
create table hmda_2a as select a.*, b.zcta5
from hmda_2 as a left join dlr.link_zip1 as b
on a.fips_code = b.fips_code and a.census_tract = b.tract; 
quit;

*Delete observations with missing ZIP code identifiers;
data hmda_2a; set hmda_2a; 
if zcta5=. then delete;
run;

*Create the jumbo loan indicator using the threshold;
proc sql;
create table hmda_2a as select a.*, b.one as one_1
from hmda_2a as a left join dlr.jumbo_2009_2016 as b
on a.year = b.year and a.fips_code = b.fips_code; 
quit;

proc sql;
create table hmda_2a as select a.*, b.one as one_2
from hmda_2a as a left join dlr.jumbo_2007_2008 as b
on a.year = b.year and a.fips_code = b.fips_code; 
quit;

proc sql;
create table hmda_2a as select a.*, b.one as one_3
from hmda_2a as a left join dlr.jumbo_1980_2007 as b
on a.year = b.year; 
quit;

data hmda_2a; set hmda_2a;
if one_2=. then one_2=one_3;
run;

data hmda_2a (drop=one_2 one_3); set hmda_2a;
if one_1=. then one_1=one_2;
run;

data hmda_2a; set hmda_2a;
if loantype=1 and amount>one_1 then jumbo=1; else jumbo=0;
if loantype=1 and amount<=one_1 then nonjumbo=1; else nonjumbo=0;
run;

*Import the link file between Call Reports and HMDA using the reporter panel; 
proc sql;
create table hmda_6 as select a.*, b.respondent_rssd_id
from hmda_2a as a left join hmda.hmda_reporter_nac as b
on a.bankid = b.respondent_id and a.agency = b.agency_code and a.year = b.year; 
quit;

*Import bank-level variables and link them to the HMDA data;
proc sql;
create table hmda_6 as select a.*, b.rssd9001 as mergeid, b.delr_avg as delr_current, b.asset, b.lnat, b.lag_tieronecap, b.lag_alwn,
b.npl, b.cash, b.deposit, b.liq, b.llr, b.roa, b.public, b.d_min
from hmda_6 as a left join dlr.delr_call as b
on a.year = b.year and a.respondent_rssd_id = b.rssd9001; 
quit;

proc sql;
create table hmda_6 as select a.*, b.delr_pre, b.delr_h as delr_h_bank
from hmda_6 as a left join dlr.delr_pre as b
on a.respondent_rssd_id = b.mergeid; 
quit;

*Create Off-Balance-Sheet Rate by bank and year;
proc sql;
create table hmda_6 as
select *, mean(sold) as off_bs_rate
from hmda_6
group by year, bankid;
quit;

*Delete observations without bank identifiers;
data hmda_7; set hmda_6;
drop respondent_rssd_id;
if mergeid=. or mergeid=0 then delete;
run;

*Combine regional characteristics with the HMDA Data;
proc sql;
create table hmda_7 as select a.*, b.g_emp, b.g_est
from hmda_7 as a left join dlr.cbp as b
on a.zcta5 = b.zipcode and a.year = b.year; 
quit;

proc sql;
create table hmda_7 as select a.*, b.g_gross_income, b.avg_income
from hmda_7 as a left join dlr.irs_all as b
on a.zcta5 = b.zipcode and a.year = b.year; 
quit;

proc sql;
create table hmda_7 as select a.*, b.*
from hmda_7 as a left join dlr.census_zip as b
on a.zcta5 = b.zip_code; 
quit;

*Import ZIP-code-level for Exposure High variable;
data zip_delr; set dlr.hmda_13; 
run;

proc sort data=zip_delr out=zip_delr nodupkey;
by zcta5;
run;

*Combine Exposure High variable;
proc sql;
create table hmda_7 as select a.*, b.delr_r_h
from hmda_7 as a left join zip_delr as b
on a.zcta5 = b.zcta5; 
quit;

proc sort data=hmda_7 out=hmda_7;
by mergeid year;
run;

*Create control variables;
data hmda_7; set hmda_7;
lnincome=log(income);
loan_to_income=amount/income;
lnamount=log(amount);
ln_avg_income = log(avg_income);
run;

*Delete observations with missing controls;
data hmda_7; set hmda_7;
_TYPE_=0;
if year<2004 then delete;
if year>2009 then delete;
if delr_pre=. then delete;
if lnat=. then delete;
if lag_tieronecap=. then delete;
if npl=. then delete;
if cash=. then delete;
if deposit=. then delete;
if liq=. then delete;
if llr=. then delete;
if roa=. then delete;
if off_bs_rate=. then delete;
if lnincome=. then delete;
if lnamount=. then delete;
if loan_to_income=. then delete;
run;

*Create High Cap1 and High ALWN variables;
proc sort data=hmda_7 out=hmda_7a nodupkey;
by year mergeid;
run; 

proc means data=hmda_7a noprint;
output out=hmda_7b 
p50(lag_tieronecap lag_alwn)=lag_tieronecap_med lag_alwn_med;
by year;
quit; 

proc sql;
create table hmda_7 as select a.*, b.lag_tieronecap_med, b.lag_alwn_med 
from hmda_7 as a left join hmda_7b as b
on a.year = b.year; 
quit;

data hmda_7 (drop=lag_tieronecap_med lag_lnat_med lag_alwn_med); set hmda_7;
if lag_tieronecap>lag_tieronecap_med then lag_tieronecap_h=1; else lag_tieronecap_h=0;
if lag_alwn>lag_alwn_med then lag_alwn_h=1; else lag_alwn_h=0;
run;

*Macro to winsorize variables;
%include 'C:\Dropbox\Securitization\Data_and_Code\macro_winsor.sas';
%winsor(dsetin=hmda_7, dsetout=hmda_out, byvar=none, 
vars=delr_pre lnat cash deposit lag_tieronecap liq llr npl roa off_bs_rate amount income lnincome lnamount loan_to_income
g_emp g_est g_gross_income avg_income ln_avg_income total_population black_population_pct hispanic_population_pct highschool_higher_pct 
bachelor_higher_pct poverty_pct unemployment_rate, type=winsor, pctl=1 99);

*Export the application data in STATA format;
PROC EXPORT DATA= hmda_out
            OUTFILE= "C:\Dropbox\Securitization\Submission\JAR - Final\delr_application.dta" 
            DBMS=STATA REPLACE;
RUN;

proc datasets library=work kill nolist;
quit;

/*Starting from here, I create bank-MSA-level data.*/
*Import the HMDA data of 2004 - 2010;
data hmda_2(drop=ethnic_co race2-race5 race_co1-race_co5 sex_co denial1-denial3 spread edit VAR38_ popul minority
med_income income_pct ownerunit familyunit date); set hmda.hmda_2004-hmda.hmda_2010; 
if state=. or state=2 or state=15 or state=66 or state=69 or state=72 or state=78 then delete;
if action=. or MSA="" or county="" or race1=. or loantype=. or propertytype=. or lien=. or sex=. or ethnic=. or occupancy=. then delete; 
if action=1;
if amount <=1 then delete;
if income <=10 then delete;
if loanpurpose in (1,3);
if loantype in (1,2);
if loantype=1 then conventional=1; else conventional=0;
if loantype=2 then fha=1; else fha=0;
if purchaser=0 then sold=0; else sold=1;
if propertytype=1 ;
if agency=7 then nonbank=1; else nonbank=0;
census_tract=tract*100;
state_new = put(state,2.);
fips1 = cat(state_new,county); 
fips_code = fips1*1;
msa_code = msa*1;
drop fips1 state_new;
run;

*Import the link file between census tracts to ZIP codes;
proc sql;
create table hmda_2a as select a.*, b.zcta5
from hmda_2 as a left join dlr.link_zip1 as b
on a.fips_code = b.fips_code and a.census_tract = b.tract; 
quit;

*Delete observations without MSA identifier;
data hmda_2a; set hmda_2a; 
if msa_code=. then delete;
run;

*Create the jumbo loan indicator using the threshold;
proc sql;
create table hmda_2a as select a.*, b.one as one_1
from hmda_2a as a left join dlr.jumbo_2009_2016 as b
on a.year = b.year and a.fips_code = b.fips_code; 
quit;

proc sql;
create table hmda_2a as select a.*, b.one as one_2
from hmda_2a as a left join dlr.jumbo_2007_2008 as b
on a.year = b.year and a.fips_code = b.fips_code; 
quit;

proc sql;
create table hmda_2a as select a.*, b.one as one_3
from hmda_2a as a left join dlr.jumbo_1980_2007 as b
on a.year = b.year; 
quit;

data hmda_2a; set hmda_2a;
if one_2=. then one_2=one_3;
run;

data hmda_2a (drop=one_2 one_3); set hmda_2a;
if one_1=. then one_1=one_2;
run;

data hmda_2a; set hmda_2a;
if loantype=1 and amount>one_1 then jumbo=1; else jumbo=0;
if loantype=1 and amount<=one_1 then nonjumbo=1; else nonjumbo=0;
run;

*Import the link file between Call Reports and HMDA using the reporter panel; 
proc sql;
create table hmda_2a as select a.*, b.respondent_rssd_id
from hmda_2a as a left join hmda.hmda_reporter_nac as b
on a.bankid = b.respondent_id and a.agency = b.agency_code and a.year = b.year; 
quit;

*Import bank-level variables and link them to the HMDA data;
proc sql;
create table hmda_2a as select a.*, b.rssd9001 as mergeid, b.delr_avg as delr_current, b.lag_delr_avg as lag_delr_current, b.delr_pre, 
b.delr_2001, b.delr_2006, b.alwn, b.alwn_pre, b.lag_alwn, b.alwn_2001, b.alwn_2006, b.asset, b.lag_at, b.lag_lnat, b.lnat, b.lag_tieronecap,
b.npl, b.cash, b.deposit, b.liq, b.llr, b.roa, b.public, b.d_min
from hmda_2a as a left join dlr.delr_call as b
on a.year = b.year and a.respondent_rssd_id = b.rssd9001; 
quit;

*Import DLR High variable;
proc sql;
create table hmda_2a as select a.*, b.delr_h as delr_h_bank
from hmda_2a as a left join dlr.delr_pre as b
on a.respondent_rssd_id = b.mergeid; 
quit;

*Create DLR Low variable;
data hmda_2a; set hmda_2a;
if delr_h_bank = 0 then delr_l_bank = 1; else delr_l_bank = 0;
run;

*Compute mortgages issued by all, high-DLR banks, low-DLR banks, and nonbanks by MSA and year;
proc sql;
create table hmda_3 as
select *, sum(amount) as amount_msa, sum(amount*delr_h_bank) as amount_msa_delr_h, sum(amount*delr_l_bank) as amount_msa_delr_l,
sum(amount*nonbank) as amount_msa_nonbank
from hmda_2a
group by year, msa_code;
quit;

*Compute mortgages issued by bank, MSA, and year for different types of mortgages;
proc sql;
create table hmda_4 as
select *, sum(amount) as amount_ins, sum(amount*conventional) as conven_ins, sum(amount*jumbo*conventional) as jumbo_ins,
sum(amount*nonjumbo*conventional) as nonjumbo_ins, sum(amount*fha) as fha_ins
from hmda_3
group by year, msa_code, bankid;
quit;

*Compute mortgages issued by bank and year for different types of mortgages;
proc sql;
create table hmda_4 as
select *, sum(amount) as amount_ins_all, sum(amount*conventional) as conven_ins_all, sum(amount*jumbo*conventional) as jumbo_ins_all,
sum(amount*nonjumbo*conventional) as nonjumbo_ins_all, sum(amount*fha) as fha_ins_all, mean(sold) as off_bs_rate
from hmda_4
group by year, bankid;
quit;

*Keep only one observation for each bank-MSA-year;
proc sort data=hmda_4 out=hmda_5 nodupkey;
by year msa_code bankid;
run;

*Compute market shares by bank;
data hmda_5; set hmda_5; 
marketshare=amount_ins/amount_msa;
run;

*Compute HHI index by MSA and year;
proc sql;
create table hmda_5 as
select *, sum(marketshare**2) as hhi
from hmda_5
group by year, msa_code;
quit;

*Compute big 4 market shares and number of lenders by MSA and year;
proc sort data=hmda_5;
by year msa_code descending marketshare;
run;
data hmda_6; set hmda_5;
by year msa_code;
retain counter big4 .;
if first.msa_code then do; 
big4 = 0;
counter = 1;
end;
if counter le 4 then do;
big4 = sum(big4,marketshare);
end;
if last.year or last.msa_code then do;
output;
end;
counter = counter+1;
run;

**Combine big4 market shares and number of lenders with the HMDA data;
proc sql;
create table hmda_7 as select a.*, b.big4, b.counter as no_lender
from hmda_5 as a left join hmda_6 as b
on a.year = b.year and a.msa_code = b.msa_code; 
quit;

*Compute nonbank market shares;
proc sql;
create table hmda_7 as
select *, sum(marketshare*nonbank) as nonbank_share
from hmda_7
group by year, msa_code;
quit;

*Import MSA population from the Census data;
proc sql;
create table hmda_7 as select a.*, b.total_population
from hmda_7 as a left join dlr.census_msa as b
on a.msa_code = b.msa; 
quit;

*Keep only necessary variables;
data hmda_7; set hmda_7;
drop agency loantype loanpurpose occupancy amount action sex income purchaser propertytype preapprove 
ethnic race1 hoepa lien popul minority med_income income_pct ownerunit familyunit date conventional fha approve 
one_1 jumbo nonjumbo respondent_rssd_id;
run;

*Compute regression variables;
data hmda_7; set hmda_7;
amount_ins_ms=amount_ins/amount_msa*100;
conven_ins_ms=conven_ins/amount_msa*100;
fha_ins_ms=fha_ins/amount_msa*100;
diff_ins_ms=(conven_ins - fha_ins)/amount_msa*100;
ln_amount_ins=log(amount_ins);
run;

*Delete observations with missing controls;
data hmda_8a; set hmda_7;
if year<2004 then delete;
if year>2009 then delete;
if mergeid=. or mergeid=0 then delete;
if amount_ins_ms=. then delete;
if delr_h_bank=. then delete;
if total_population=. then delete;
if delr_pre=. then delete;
if delr_h_bank=. then delete;
if lnat=. then delete;
if cash=. then delete;
if deposit=. then delete;
if lag_tieronecap=. then delete;
if liq=. then delete;
if llr=. then delete;
if npl=. then delete;
if roa=. then delete;
if off_bs_rate=. then delete;
run;

*Create High Cap1 and High ALWN variables;
proc sort data=hmda_8a out=hmda_8b nodupkey;
by year mergeid;
run; 

proc means data=hmda_8b noprint;
output out=hmda_8c 
p50(lag_tieronecap lag_at lag_lnat lag_alwn)=lag_tieronecap_med lag_at_med lag_lnat_med lag_alwn_med;
by year;
quit; 

proc sql;
create table hmda_8a as select a.*, b.lag_tieronecap_med, b.lag_at_med, b.lag_lnat_med, b.lag_alwn_med 
from hmda_8a as a left join hmda_8c as b
on a.year=b.year; 
quit;

data hmda_8a (drop=lag_tieronecap_med); set hmda_8a;
if lag_tieronecap>lag_tieronecap_med then lag_tieronecap_h=1; else lag_tieronecap_h=0;
if lag_at>lag_at_med then lag_at_h=1; else lag_at_h=0;
if lag_lnat>lag_lnat_med then lag_lnat_h=1; else lag_lnat_h=0;
if lag_alwn>lag_alwn_med then lag_alwn_h=1; else lag_alwn_h=0;
run;

proc sort data=hmda_8a;
by year msa_code bankid;
run;

*Macro to winsorize variables;
%include 'C:\Dropbox\Securitization\Data_and_Code\macro_winsor.sas';
%winsor(dsetin=hmda_8a, dsetout=hmda_8_out, byvar=none, 
vars= delr_current lag_delr_current delr_pre delr_2001 delr_2006 alwn lag_alwn alwn_2001 alwn_2006 
asset lnat cash deposit lag_tieronecap liq llr npl roa off_bs_rate
ln_amount_ins amount_ins_all conven_ins_all jumbo_ins_all nonjumbo_ins_all fha_ins_all
amount_ins conven_ins jumbo_ins nonjumbo_ins fha_ins amount_ins_ms conven_ins_ms fha_ins_ms diff_ins_ms
amount_msa amount_msa_delr_h amount_msa_delr_l 
hhi big4 no_lender nonbank_share, type=winsor, pctl=1 99);

*Export the bank-MSA-level data in STATA format;
PROC EXPORT DATA= WORK.hmda_8_out 
            OUTFILE= "C:\Dropbox\Securitization\Submission\JAR - Final\delr_msa.dta" 
            DBMS=STATA REPLACE;
RUN;

