ods graphics off;

*Designate library names for data folders;
libname hmda "D:\Data\HMDA"; /*folder for the HMDA data*/
libname dlr "C:\Dropbox\Securitization\Submission\JAR - Final"; /*folder for the main folder for the project*/

*Import Dataquick transaction data;
data transact_2; set dlr.transact;
if sr_property_id=. then delete;
if sr_tran_type in ('S','R');
if sr_arms_length_flag='1';
if mm_fips_state_code=. or mm_fips_state_code=2 or mm_fips_state_code=15 or mm_fips_state_code=66 or mm_fips_state_code=69 or mm_fips_state_code=72 or mm_fips_state_code=78 then delete;
year=year(sr_date_transfer);
if year(sr_date_transfer) < 2004 or year(sr_date_transfer) > 2010 then delete;
run;

proc sql;
create table transact_2 as select a.*, b.sa_property_id, b.sa_site_zip
from transact_2 as a left join dlr.assess as b
on a.sr_property_id = b.sa_property_id; 
quit;

data transact_3; set transact_2;
if sa_property_id=. or sa_site_zip=. or sr_unique_id=. then delete;
if sa_site_zip=0 then delete;
run;

proc sort data=transact_3 out=cleaned_1a nodupkey;
by sa_property_id sr_date_transfer descending sr_val_transfer;
run;

data cleaned_1a; set cleaned_1a; 
if distress_indicator in ('A','I','S') then dist_all=1; else dist_all=0;
if distress_indicator = 'I' then shortsale=1; else shortsale=0;
if distress_indicator in ('A','S') then foreclosure=1; else foreclosure=0;
run;

*Combine with the HMDA data;
data hmda_2(drop=ethnic_co race2-race5 race_co1-race_co5 sex_co denial1-denial3 spread edit VAR38_ popul minority
med_income income_pct ownerunit familyunit date); set hmda.hmda_2004-hmda.hmda_2006; 
if loanpurpose=1;
if loantype in (1,2);
if state=. or state=2 or state=15 or state=66 or state=69 or state=72 or state=78 then delete;
if action=. or MSA="" or county="" or race1=. or loantype=. or propertytype=. or lien=. or sex=. or ethnic=. or occupancy=. then delete; 
if action=1;
if amount <=1 then delete;
if income <=10 then delete;
if loantype=1 then conventional=1; else conventional=0;
if loantype=2 then fha=1; else fha=0;
if purchaser=0 then sold=0; else sold=1;
if propertytype=1;
if agency=7 then nonbank=1; else nonbank=0;
census_tract=tract*100;
state_new = put(state,2.);
fips1 = cat(state_new,county); 
fips_code = fips1*1;
county1 = county*1;
drop fips1 state_new;
run;

*Rename some variables of the DataQuick data;
data cleaned_1; set cleaned_1a;
rename mm_fips_state_code=state_code mm_fips_muni_code=county_code sr_date_transfer=transfer_date sr_val_transfer=transfer_val;
run;

*Import DataQuick Loan data;
proc sql;
create table cleaned_2 as select a.*, b.sr_loan_val_1 as loan_val, b.sr_lndr_first_name_1 as lender_dq
from cleaned_1 as a left join dlr.loans as b
on a.sr_unique_id = b.sr_unique_id; 
quit;

*Remove if loan values are missing;
data cleaned_2; set cleaned_2; 
if loan_val=. then delete;
run;

*Import the link file between census tracts to ZIP codes;
proc sql;
create table hmda_2 as select a.*, b.zcta5
from hmda_2 as a left join dlr.link_zip1 as b
on a.fips_code = b.fips_code and a.census_tract = b.tract; 
quit;

*Delete observations without ZIP-code identifier;
data hmda_2; set hmda_2; 
if zcta5=. then delete;
run;

*Create the jumbo loan indicator using the threshold;
proc sql;
create table hmda_2 as select a.*, b.one
from hmda_2 as a left join dlr.jumbo_1980_2007 as b
on a.year = b.year; 
quit;

data hmda_2; set hmda_2;
if loantype=1 and amount>one then jumbo=1; else jumbo=0;
if loantype=1 and amount<=one then nonjumbo=1; else nonjumbo=0;
run;

*Import the link file between Call Reports and HMDA using the reporter panel; 
proc sql;
create table hmda_2 as select a.*, b.respondent_rssd_id, b.respondent_name
from hmda_2 as a left join hmda.hmda_reporter_nac as b
on a.bankid = b.respondent_id and a.agency = b.agency_code and a.year = b.year; 
quit;

*Import bank identifiers from Call Reports;
proc sql;
create table hmda_2 as select a.*, b.rssd9001 as mergeid
from hmda_2 as a left join dlr.delr_call as b
on a.year = b.year and a.respondent_rssd_id = b.rssd9001; 
quit;

*Compute bank-level Off-Balance-Sheet-Rate;
proc sql;
create table hmda_2 as
select *, mean(sold) as off_bs_rate
from hmda_2
group by year, bankid;
quit;

*Delete observations without bank ID;
data hmda_2; set hmda_2; 
if mergeid=. or mergeid=0 then delete;
run;

*Create an index for observations;
data hmda_2; set hmda_2; 
id_hmda= _N_;
run;

*Matching with lender's name (Fuzzy matching);
**some names are manually corrected for better matching;
data hmda_3; set hmda_2; 
if respondent_name="BANK OF AMER FORK" then respondent_name="BANK OF AMERICAN FORK";
if respondent_name="CITIBANK NA" then respondent_name="CITI";
if respondent_name="AMERICA CA BANK" then respondent_name="AMERICA CALIFORNIA BANK";
if respondent_name="BANK OF YAZOO CITY" then respondent_name="BOFYAZOO";
if respondent_name="CENTRAL IL BANK" then respondent_name="CENTRAL ILLINOIS BANK";
if respondent_name="CENTRAL VA BANK" then respondent_name="CENTRAL VIRGINIA BANK";
if respondent_name="CHAMBERS BANK OF N AR" then respondent_name="CHAMBERS BANK N ARKANSAS";
if respondent_name="CHESTERTOWN BANK OF MD" then respondent_name="CHESTERTOWN BANK MARYLAND";
if respondent_name="AMERICAN BANK NORTH" then respondent_name="AMERICAN BANK OF THE NORTH";
if respondent_name="BANK OF WESTERN MA" then respondent_name="BANK OF WESTERN MASSACHUSETTS";
if respondent_name="BLOOMINGDALE B&T" then respondent_name="BLOOMINGDALE BANK & TRUST";
if respondent_name="CENTENNIAL BANK W" then respondent_name="CENTENNIAL BANK OF THE WEST";
if respondent_name="COMMERCE BANK/DE NA" then respondent_name="COMMERCE BANK DELAWARE NA";
if respondent_name="COMMERCIAL BANK OF VOLUSIA COU" then respondent_name="COMMERCIAL BANK VOLUSIA COUNTY";
if respondent_name="COMMERCIAL ST BANK OF WATERLOO" then respondent_name="COMMERCIAL STATE BANK WATERLOO";
if respondent_name="COMMUNITY BANK & TRUST OF CHEA" then respondent_name="COMMUNITY BANK & TRUST CHEATHM";
if respondent_name="COMMUNITY BANK OF CENT CA" then respondent_name="COMMUNITY BANK CENTRAL CA";
if respondent_name="COMMUNITY BANK OF THE OZARKS" then respondent_name="COMMUNITY BANK OZARKS";
if respondent_name="COMMUNITY NATIONAL BANK AT BAR" then respondent_name="COMMUNITY NATIONAL BANK BARTOW";
if respondent_name="COMMUNITY ST BANK NA" then respondent_name="COMMUNITY STATE BANK";
if respondent_name="COMMUNITY NATIONAL BANK AT BAR" then respondent_name="COMMUNITY NATIONAL BANK BARTOW";
if respondent_name="AMERICAN BANK COMMERCIAL" then respondent_name="AMERICAN BANK OF COMMERCE";
if respondent_name="AMERICAN BANK NORTH" then respondent_name="AMERICAN BANK OF THE NORTH";
if respondent_name="FIRST BANK OF MO" then respondent_name="FIRST BANK MISSOURI";
run;

**Some abbreviations are manually corrected for better matching;
data hmda_3; set hmda_3; 
respondent_name=tranwrd(respondent_name, "BK", "BANK");
respondent_name=tranwrd(respondent_name, "CMNTY", "COMMUNITY");
respondent_name=tranwrd(respondent_name, "CNMTY", "COMMUNITY");
respondent_name=tranwrd(respondent_name, "CTY", "COUNTY");
respondent_name=tranwrd(respondent_name, "NB", "NATIONAL BANK");
respondent_name=tranwrd(respondent_name, "INTRST", "INTERSTATE");
respondent_name=tranwrd(respondent_name, "INTL", "INTERNATIONAL");
respondent_name=tranwrd(respondent_name, "SVG", "SAVINGS");
respondent_name=tranwrd(respondent_name, "SB", "SAVINGS BANK");
respondent_name=tranwrd(respondent_name, "BROS", "BROTHERS");
respondent_name=tranwrd(respondent_name, "CMRC", "COMMERCIAL");
respondent_name=tranwrd(respondent_name, "CMRL", "COMMERCIAL");
respondent_name=tranwrd(respondent_name, "MRCH", "MERCHANTS");
respondent_name=tranwrd(respondent_name, "B&T", "BANK & TRUST");
respondent_name=tranwrd(respondent_name, "NB&TC", "NATIONAL BANK & TRUST");
respondent_name=tranwrd(respondent_name, "T&SB", "TRUST & SAV BANK");
respondent_name=tranwrd(respondent_name, "MSB", "MUTUAL SAVINGS BANK");
respondent_name=tranwrd(respondent_name, "MSAVINGS", "MUTUAL SAVINGS");
respondent_name=tranwrd(respondent_name, "NB", "NATIONAL BANK");
respondent_name=tranwrd(respondent_name, "CO-OP", "COOPERATIVE");
respondent_name=tranwrd(respondent_name, "FNCL", "FINANCIAL");
respondent_name=tranwrd(respondent_name, "TC", "TRUST CO");
respondent_name=tranwrd(respondent_name, "AZ", "ARIZONA");
respondent_name=tranwrd(respondent_name, "TX", "TEXAS");
respondent_name=tranwrd(respondent_name, "FL", "FLORIDA");
respondent_name=tranwrd(respondent_name, "NJ", "NEW JERSEY");
respondent_name=tranwrd(respondent_name, "WV", "W VIRGINIA");
run;

*Compress spaces in the lender name, extract the first eight characters;
data hmda_3; set hmda_3; 
lender_hmda=compress(respondent_name);
lender=substr(lender_hmda,1,8);
run;

*Remove loans likely issued by nonbank lenders;
data cleaned_3; set cleaned_2; 
loan_amt=int(loan_val/1000);
if lender_dq="CITIBANK NA" then lender_dq="CITI";
if lender_dq="BANK OF YAZOO CTY" then lender_dq="BOFYAZOO";
if find(lender_dq,"MORTGAGE") then delete;
if find(lender_dq,"MTG") then delete;
if find(lender_dq,"MRTG") then delete;
if find(lender_dq,"HOME LOAN") then delete;
if find(lender_dq,"HOUSING") then delete;
if find(lender_dq,"HEALTH") then delete;
if find(lender_dq,"SERVICES") then delete;
if find(lender_dq,"FCU") then delete;
if find(lender_dq,"WELLS FARGO FIN'L SC") then delete;
if find(lender_dq,"WELLS FARGO FINANCE") then delete;
if find(lender_dq,"WELLS FARGO FINANCIAL") then delete;
run;

**More names are manually corrected for better matching;
data cleaned_3; set cleaned_3; 
lender_dq=tranwrd(lender_dq, "BK", "BANK");
lender_dq=tranwrd(lender_dq, "NAT'L", "NATIONAL");
lender_dq=tranwrd(lender_dq, "VLY", "VALLEY");
lender_dq=tranwrd(lender_dq, "BK & TR", "BANK & TRUST");
lender_dq=tranwrd(lender_dq, "INT'L", "INTERNATIONAL");
lender_dq=tranwrd(lender_dq, "BK/RED", "BANK RED");
run;

**Compress spaces in the lender name, extract the first eight characters;
data cleaned_3; set cleaned_3; 
lender_daq=compress(lender_dq);
lender=substr(lender_daq,1,8);
run;

**Match each transaction to a mortgage in HMDA based on year, ZIP code, lender name, and exact loan amount;
proc sql;
create table matched_1 as select a.*, b.mergeid, b.respondent_name, b.lender_hmda, b.id_hmda
from cleaned_3 as a left join hmda_3 as b
on a.year = b.year and a.state_code = b.state and a.county_code = b.county1 and a.sa_site_zip = b.zcta5 and a.loan_amt = b.amount and a.lender = b.lender; 
quit;

**Delete matches if the cost is more than 500;
data matched_2; set matched_1; 
if mergeid=. then delete;
cost=compged(lender_dq,respondent_name);
if cost>500 then delete;
run;

proc sort data=matched_2 out=matched_2;
by sr_unique_id;
run;

**If there are multiple matches, one of them is randomly assigned as a match, and unassigned matches are dropped;
data matched_2; set matched_2; by sr_unique_id;
count+1;
if first.sr_unique_id then count=1;
run;

proc surveyselect data=matched_2 out=matched_3 noprint
method=srs seed=100 N=1 ; strata sr_unique_id; options nonotes; quit;

proc sql;
create table matched_4 as select a.*, b.id_hmda
from cleaned_1 as a left join matched_3 as b
on a.sr_unique_id = b.sr_unique_id; 
quit;

**I conduct the same match procedure based on year, ZIP code, lender name but allow loan amounts to differ by  $1,000;
proc sql;
create table matched_1a as select a.*, b.mergeid, b.respondent_name, b.lender_hmda, b.id_hmda
from cleaned_3 as a left join hmda_3 as b
on a.year = b.year and a.state_code = b.state and a.county_code = b.county1 and a.sa_site_zip = b.zcta5 and a.loan_amt = b.amount-1 and a.lender = b.lender; 
quit;
data matched_1a; set matched_1a; 
if mergeid=. then delete;
run;

proc sql;
create table matched_1b as select a.*, b.mergeid, b.respondent_name, b.lender_hmda, b.id_hmda
from cleaned_3 as a left join hmda_3 as b
on a.year = b.year and a.state_code = b.state and a.county_code = b.county1 and a.sa_site_zip = b.zcta5 and a.loan_amt = b.amount+1 and a.lender = b.lender; 
quit;
data matched_1b; set matched_1b; 
if mergeid=. then delete;
run;

data matched_1c; set matched_1a matched_1b;
run;

data matched_2a; set matched_1c; 
if mergeid=. then delete;
cost=compged(lender_dq,respondent_name);
if cost>500 then delete;
run;

proc sort data=matched_2a out=matched_2a;
by sr_unique_id;
run;

data matched_2a; set matched_2a; by sr_unique_id;
count+1;
if first.sr_unique_id then count=1;
run;

proc surveyselect data=matched_2a out=matched_3a noprint
method=srs seed=100 N=1 ; strata sr_unique_id; options nonotes; quit;

proc sql;
create table matched_4 as select a.*, b.id_hmda as id_hmda_a
from matched_4 as a left join matched_3a as b
on a.sr_unique_id = b.sr_unique_id; 
quit;

data matched_4; set matched_4; 
if id_hmda=. then id_hmda=id_hmda_a;
run;

proc sql;
create table matched_4 as
select *, max(id_hmda) as id_hmda_max
from matched_4
group by sa_property_id;
quit;

data matched_4; set matched_4;
if id_hmda_max=. then delete;
run;

proc sql;
create table matched_4 as select a.*, b.*
from matched_4 as a left join hmda_3 as b
on a.id_hmda = b.id_hmda; 
quit;

data matched_4; set matched_4;
drop lender_dq lender lender_daq lender_hmda state_code county_code cost count selectionprob sampling weight bankid
tract respondent_rssd_id id_hmda_max id_hmda_a; 
run;

proc sort data=matched_4;
by sa_property_id descending transfer_date;
run;

data matched_4; set matched_4; by sa_property_id descending transfer_date;
lead_transfer_date=lag(transfer_date); lead_distress_indicator=lag(distress_indicator);
if first.sa_property_id then do; 
lead_transfer_date=.; lead_distress_indicator=.;
end;
run;

*Remove observations without bank ID and create indicators for distressed sales;
data matched_5; set matched_4;
if mergeid=. then delete;
lead_year=year(lead_transfer_date);
if lead_distress_indicator in ('A','I','S') and lead_year>2006 then dist_all=1; else dist_all=0;
if lead_distress_indicator = 'I' and lead_year>2006 then shortsale=1; else shortsale=0;
if lead_distress_indicator in ('A','S') and lead_year>2006 then foreclosure=1; else foreclosure=0;
run;

*Make sure to keep only one observation for each property;
proc sort data=matched_5 out=matched_5 nodupkey;
by id_hmda;
run;

*Import bank-level variables;
proc sql;
create table matched_5 as select a.*, b.delr_pre, b.delr_h as delr_h_bank
from matched_5 as a left join dlr.delr_pre as b
on a.mergeid = b.mergeid; 
quit;

proc sql;
create table matched_5 as select a.*, b.asset, b.lnat, b.lag_tieronecap, 
b.npl, b.cash, b.deposit, b.liq, b.llr, b.roa, b.public, b.d_min,
b.lnat_pre, b.tieronecap_pre, b.npl_pre, b.cash_pre, b.deposit_pre, b.liq_pre, b.llr_pre, b.roa_pre,
b.lnat_post, b.tieronecap_post, b.npl_post, b.cash_post, b.deposit_post, b.liq_post, b.llr_post, b.roa_post
from matched_5 as a left join dlr.delr_call as b
on a.year = b.year and a.mergeid = b.rssd9001; 
quit;

*Combine regional characteristics with the HMDA Data;
**Employment and Business Establishements from CBP;
proc sql;
create table matched_5 as select a.*, b.g_emp, b.g_est
from matched_5 as a left join dlr.cbp as b
on a.zcta5 = b.zipcode and a.year = b.year; 
quit;

**Income growth and average income from IRS;
proc sql;
create table matched_5 as select a.*, b.g_gross_income, b.avg_income
from matched_5 as a left join dlr.irs_all as b
on a.zcta5 = b.zipcode and a.year = b.year; 
quit;

**Demographics, poverty, and education data are from Census;
proc sql;
create table matched_5 as select a.*, b.*
from matched_5 as a left join dlr.census_zip as b
on a.zcta5 = b.zip_code; 
quit;

*Import ZIP-code-level for Exposure High variable;
data zip_delr; set dlr.hmda_13; 
run;

proc sort data=zip_delr out=zip_delr nodupkey;
by zcta5;
run;

*Combine Exposure High variable;
proc sql;
create table matched_5 as select a.*, b.delr_r_h
from matched_5 as a left join zip_delr as b
on a.zcta5 = b.zcta5; 
quit;

*Import ZIP-code-level variables;
proc sql;
create table matched_5 as select a.*, b.lag_tieronecap_zip, b.hhi, b.nonbank_share, b.d_amt_zip_nonbank, b.ms_h_pre
from matched_5 as a left join dlr.hmda_13 as b
on a.zcta5 = b.zcta5 and a.year = b.year; 
quit;

*Create control variables;
data matched_5; set matched_5;
lnincome=log(income);
loan_to_income=amount/income;
lnamount=log(amount);
ln_avg_income = log(avg_income);
ln_pop = log(total_population);
run;

*Delete observations with missing controls;
data matched_6; set matched_5;
if delr_pre=. then delete;
if delr_r_h=. then delete;
if lnat=. then delete;
if lag_tieronecap=. then delete;
if npl=. then delete;
if cash=. then delete;
if deposit=. then delete;
if liq=. then delete;
if llr=. then delete;
if roa=. then delete;
if off_bs_rate=. then delete;
if lag_tieronecap_zip=. then delete;
if g_emp=. then delete;
if g_est=. then delete;
if g_gross_income=. then delete;
if avg_income=. then delete;
if hhi=. then delete;
if nonbank_share=. then delete;
if d_amt_zip_nonbank=. then delete;
if ln_avg_income=. then delete;
if ln_pop=. then delete;
run;

*Macro to winsorize variables;
%include 'C:\Dropbox\Securitization\Data_and_Code\macro_winsor.sas';
%winsor(dsetin=matched_6, dsetout=matched_dq, byvar=none, 
vars=delr_pre lnat cash deposit lag_tieronecap liq llr npl roa off_bs_rate
lnat_pre tieronecap_pre npl_pre cash_pre deposit_pre liq_pre llr_pre roa_pre
lnat_post tieronecap_post npl_post cash_post deposit_post liq_post llr_post roa_post
amount income lnincome lnamount loan_to_income lag_tieronecap_zip hhi nonbank_share d_amt_zip_nonbank ms_h_pre
g_emp g_est g_gross_income avg_income ln_avg_income total_population black_population_pct hispanic_population_pct highschool_higher_pct 
bachelor_higher_pct poverty_pct unemployment_rate, type=winsor, pctl=1 99);

*Export the matched-loan-level data in STATA format;
PROC EXPORT DATA= matched_dq
            OUTFILE= "C:\Dropbox\Securitization\Submission\JAR - Final\matched_loan.dta" 
            DBMS=STATA REPLACE;
RUN;
